Module application

Module application 

Re-exports

pub use box_future::BoxFuture;
pub use subscription::Recipe;
pub use subscription::Subscription;
pub use task::Task;

Modules

box_future
BoxFuture: the boxed future type shared by Task and Subscription.
subscription
Long-lived message sources composed of one or more Recipes.
task
Side-effecting work container returned from init/update.

Traits

Application
An application running under the Runtime.