pub struct Constraints {
pub min: Size,
pub max: Size,
}Expand description
Min and max bounds a parent gives a child during the measure pass.
Children should return a size satisfying min <= size <= max on both
axes. The UNBOUNDED sentinel in a max field means “as much as you
want.”
Fields
min: SizeMinimum size the child must produce.
max: SizeMaximum size the child may produce.
Implementations
Sourceimpl Constraints
impl Constraints
Sourcepub fn clamp(&self, size: Size) -> Size
pub fn clamp(&self, size: Size) -> Size
Clamp size to fall within the constraints on both axes.
Sourcepub fn with_width(self, w: u32) -> Self
pub fn with_width(self, w: u32) -> Self
Constraints with max.width = w. min.width is also clamped to w
to preserve min <= max.
Sourcepub fn with_height(self, h: u32) -> Self
pub fn with_height(self, h: u32) -> Self
Constraints with max.height = h. min.height is also clamped.